aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorMichael Mattioli <mmattioli@users.noreply.github.com>2017-04-17 22:16:37 -0400
committerGreg Hudson <ghudson@mit.edu>2017-04-20 12:33:20 -0400
commit2f3194da85a7e1e86b4aada814ff35e87710b4ab (patch)
treed8674ad999223574f17e79b653f3c0c1bdc1ea6f /src
parente71a52662323d1055076a95060f28a6e8963788c (diff)
downloadkrb5-2f3194da85a7e1e86b4aada814ff35e87710b4ab.zip
krb5-2f3194da85a7e1e86b4aada814ff35e87710b4ab.tar.gz
krb5-2f3194da85a7e1e86b4aada814ff35e87710b4ab.tar.bz2
Replace references to OS X
Replace references to Apple OS X with the updated OS name "macOS" where applicable.
Diffstat (limited to 'src')
-rw-r--r--src/ccapi/server/mac/ccs_os_pipe.c4
-rw-r--r--src/config/pre.in6
-rw-r--r--src/configure.in6
-rw-r--r--src/include/fake-addrinfo.h2
-rw-r--r--src/include/k5-platform.h2
-rw-r--r--src/include/krb5/krb5.hin6
-rw-r--r--src/lib/apputils/udppktinfo.c2
-rw-r--r--src/lib/apputils/udppktinfo.h2
-rw-r--r--src/lib/crypto/builtin/des/des_int.h2
-rw-r--r--src/lib/krb5/ccache/cc_kcm.c4
-rw-r--r--src/lib/krb5/krb/gic_opt.c2
-rw-r--r--src/lib/krb5/krb/pac.c4
-rw-r--r--src/lib/krb5/os/dnsglue.c2
-rw-r--r--src/lib/krb5/os/dnsglue.h6
-rw-r--r--src/lib/krb5/os/sendto_kdc.c2
-rw-r--r--src/man/krb5.conf.man2
-rw-r--r--src/util/depfix.pl2
-rw-r--r--src/util/support/cache-addrinfo.h12
-rw-r--r--src/util/support/fake-addrinfo.c4
19 files changed, 36 insertions, 36 deletions
diff --git a/src/ccapi/server/mac/ccs_os_pipe.c b/src/ccapi/server/mac/ccs_os_pipe.c
index 67f9030..5d9fff2 100644
--- a/src/ccapi/server/mac/ccs_os_pipe.c
+++ b/src/ccapi/server/mac/ccs_os_pipe.c
@@ -27,7 +27,7 @@
#include "ccs_os_pipe.h"
#include <mach/port.h>
-/* On Mac OS X ccs_pipe_t is a mach_port_t */
+/* On macOS ccs_pipe_t is a mach_port_t */
/* ------------------------------------------------------------------------ */
@@ -73,7 +73,7 @@ cc_int32 ccs_os_pipe_release (ccs_pipe_t io_pipe)
{
cc_int32 err = 0;
- /* Nothing to do here on Mac OS X */
+ /* Nothing to do here on macOS */
return cci_check_error (err);
}
diff --git a/src/config/pre.in b/src/config/pre.in
index b5a9f98..db50d2d 100644
--- a/src/config/pre.in
+++ b/src/config/pre.in
@@ -7,7 +7,7 @@
# srcdir=@srcdir@
# top_srcdir=@top_srcdir@
# but these are only set by autoconf 2.53, and thus not useful to us on
-# Mac OS X yet (as of 10.2):
+# macOS yet (as of 10.2):
# abs_srcdir=@abs_srcdir@
# abs_top_srcdir=@abs_top_srcdir@
# builddir=@builddir@
@@ -402,10 +402,10 @@ HESIOD_LIBS = @HESIOD_LIBS@
KRB5_BASE_LIBS = $(KRB5_LIB) $(K5CRYPTO_LIB) $(COM_ERR_LIB) $(SUPPORT_LIB) $(GEN_LIB) $(LIBS) $(DL_LIB)
KDB5_LIBS = $(KDB5_LIB) $(GSSRPC_LIBS)
GSS_LIBS = $(GSS_KRB5_LIB)
-# needs fixing if ever used on Mac OS X!
+# needs fixing if ever used on macOS!
GSSRPC_LIBS = -lgssrpc $(GSS_LIBS)
KADM_COMM_LIBS = $(GSSRPC_LIBS)
-# need fixing if ever used on Mac OS X!
+# need fixing if ever used on macOS!
KADMSRV_LIBS = -lkadm5srv_mit $(HESIOD_LIBS) $(KDB5_LIBS) $(KADM_COMM_LIBS)
KADMCLNT_LIBS = -lkadm5clnt_mit $(KADM_COMM_LIBS)
diff --git a/src/configure.in b/src/configure.in
index 6b5ac6b..65fe7c7 100644
--- a/src/configure.in
+++ b/src/configure.in
@@ -1309,7 +1309,7 @@ if test "${localedir+set}" != set; then
fi
AC_SUBST(localedir)
-# For KCM lib/krb5/ccache to build KCM Mach RPC support for OS X only.
+# For KCM lib/krb5/ccache to build KCM Mach RPC support for macOS only.
case $host in
*-*-darwin* | *-*-rhapsody*) OSX=osx ;;
*) OSX=no ;;
@@ -1343,10 +1343,10 @@ dnl brackets in the glob patterns.
if test "${DEFCCNAME+set}" != set; then
[case $host in
*-*-darwin[0-9].* | *-*-darwin10.*)
- # Use the normal default for OS X 10.6 (Darwin 10) and prior.
+ # Use the normal default for macOS 10.6 (Darwin 10) and prior.
;;
*-*-darwin*)
- # For OS X 10.7 (Darwin 11) and later, the native ccache uses
+ # For macOS 10.7 (Darwin 11) and later, the native ccache uses
# the KCM daemon.
DEFCCNAME=KCM:
;;
diff --git a/src/include/fake-addrinfo.h b/src/include/fake-addrinfo.h
index 03666a0..80ca9f8 100644
--- a/src/include/fake-addrinfo.h
+++ b/src/include/fake-addrinfo.h
@@ -52,7 +52,7 @@
the data structures and flag values locally.
- On Mac OS X, getaddrinfo results aren't cached (though
+ On macOS, getaddrinfo results aren't cached (though
gethostbyname results are), so we need to build a cache here. Now
things are getting really messy. Because the cache is in use, we
use getservbyname, and throw away thread safety. (Not that the
diff --git a/src/include/k5-platform.h b/src/include/k5-platform.h
index 62d1e2a..d58710b 100644
--- a/src/include/k5-platform.h
+++ b/src/include/k5-platform.h
@@ -512,7 +512,7 @@ typedef struct { int error; unsigned char did_run; } k5_init_t;
Linux: byteswap.h, bswap_16 etc.
Solaris 10: none
- Mac OS X: machine/endian.h or byte_order.h, NXSwap{Short,Int,LongLong}
+ macOS: machine/endian.h or byte_order.h, NXSwap{Short,Int,LongLong}
NetBSD: sys/bswap.h, bswap16 etc. */
#if defined(HAVE_BYTESWAP_H) && defined(HAVE_BSWAP_16)
diff --git a/src/include/krb5/krb5.hin b/src/include/krb5/krb5.hin
index 58a2707..762900e 100644
--- a/src/include/krb5/krb5.hin
+++ b/src/include/krb5/krb5.hin
@@ -8248,9 +8248,9 @@ krb5_pac_parse(krb5_context context, const void *ptr, size_t len,
* If successful, @a pac is marked as verified.
*
* @note A checksum mismatch can occur if the PAC was copied from a cross-realm
- * TGT by an ignorant KDC; also Apple Mac OS X Server Open Directory (as of
- * 10.6) generates PACs with no server checksum at all. One should consider
- * not failing the whole authentication because of this reason, but, instead,
+ * TGT by an ignorant KDC; also macOS Server Open Directory (as of 10.6)
+ * generates PACs with no server checksum at all. One should consider not
+ * failing the whole authentication because of this reason, but, instead,
* treating the ticket as if it did not contain a PAC or marking the PAC
* information as non-verified.
*
diff --git a/src/lib/apputils/udppktinfo.c b/src/lib/apputils/udppktinfo.c
index 9e48b47..c096c12 100644
--- a/src/lib/apputils/udppktinfo.c
+++ b/src/lib/apputils/udppktinfo.c
@@ -400,7 +400,7 @@ set_msg_from_ipv6_pktinfo(struct msghdr *msg, struct cmsghdr *cmsgptr,
/*
* Because of the possibility of asymmetric routing, we
* normally don't want to specify an interface. However,
- * Mac OS X doesn't like sending from a link-local address
+ * macOS doesn't like sending from a link-local address
* (which can come up in testing at least, if you wind up
* with a "foo.local" name) unless we do specify the
* interface.
diff --git a/src/lib/apputils/udppktinfo.h b/src/lib/apputils/udppktinfo.h
index b0c7ea3..ff5759a 100644
--- a/src/lib/apputils/udppktinfo.h
+++ b/src/lib/apputils/udppktinfo.h
@@ -32,7 +32,7 @@
* This holds whatever additional information might be needed to
* properly send back to the client from the correct local address.
*
- * In this case, we only need one datum so far: On Mac OS X, the
+ * In this case, we only need one datum so far: On macOS, the
* kernel doesn't seem to like sending from link-local addresses
* unless we specify the correct interface.
*/
diff --git a/src/lib/crypto/builtin/des/des_int.h b/src/lib/crypto/builtin/des/des_int.h
index 0801cb5..67e40a1 100644
--- a/src/lib/crypto/builtin/des/des_int.h
+++ b/src/lib/crypto/builtin/des/des_int.h
@@ -74,7 +74,7 @@
#endif /* defined(__MACH__) && defined(__APPLE__) */
/* Macro to add deprecated attribute to DES types and functions */
-/* Currently only defined on Mac OS X 10.5 and later. */
+/* Currently only defined on macOS 10.5 and later. */
#ifndef KRB5INT_DES_DEPRECATED
#define KRB5INT_DES_DEPRECATED
#endif
diff --git a/src/lib/krb5/ccache/cc_kcm.c b/src/lib/krb5/ccache/cc_kcm.c
index a889e67..b621ed3 100644
--- a/src/lib/krb5/ccache/cc_kcm.c
+++ b/src/lib/krb5/ccache/cc_kcm.c
@@ -32,7 +32,7 @@
/*
* This cache type contacts a daemon for each cache operation, using Heimdal's
- * KCM protocol. On OS X, the preferred transport is Mach RPC; on other
+ * KCM protocol. On macOS, the preferred transport is Mach RPC; on other
* Unix-like platforms or if the daemon is not available via RPC, Unix domain
* sockets are used instead.
*/
@@ -360,7 +360,7 @@ kcmio_connect(krb5_context context, struct kcmio **io_out)
return ENOMEM;
io->fd = -1;
- /* Try Mach RPC (OS X only), then fall back to Unix domain sockets */
+ /* Try Mach RPC (macOS only), then fall back to Unix domain sockets */
ret = kcmio_mach_connect(context, io);
if (ret)
ret = kcmio_unix_socket_connect(context, io);
diff --git a/src/lib/krb5/krb/gic_opt.c b/src/lib/krb5/krb/gic_opt.c
index 3be44d5..ccbe1a6 100644
--- a/src/lib/krb5/krb/gic_opt.c
+++ b/src/lib/krb5/krb/gic_opt.c
@@ -12,7 +12,7 @@
#include <TargetConditionals.h>
#endif
-/* Match struct packing of krb5_get_init_creds_opt on MacOS X. */
+/* Match struct packing of krb5_get_init_creds_opt on macOS. */
#if TARGET_OS_MAC
#pragma pack(push,2)
#endif
diff --git a/src/lib/krb5/krb/pac.c b/src/lib/krb5/krb/pac.c
index 6616dd5..485a0f7 100644
--- a/src/lib/krb5/krb/pac.c
+++ b/src/lib/krb5/krb/pac.c
@@ -791,8 +791,8 @@ mspac_verify(krb5_context kcontext,
* If the above verification failed, don't fail the whole authentication,
* just don't mark the PAC as verified. A checksum mismatch can occur if
* the PAC was copied from a cross-realm TGT by an ignorant KDC, and Apple
- * Mac OS X Server Open Directory (as of 10.6) generates PACs with no
- * server checksum at all.
+ * macOS Server Open Directory (as of 10.6) generates PACs with no server
+ * checksum at all.
*/
return 0;
}
diff --git a/src/lib/krb5/os/dnsglue.c b/src/lib/krb5/os/dnsglue.c
index 1a259b3..e29066d 100644
--- a/src/lib/krb5/os/dnsglue.c
+++ b/src/lib/krb5/os/dnsglue.c
@@ -73,7 +73,7 @@ static int initparse(struct krb5int_dns_state *);
#if defined(__APPLE__)
-/* Use the OS X interfaces dns_open, dns_search, and dns_free. */
+/* Use the macOS interfaces dns_open, dns_search, and dns_free. */
#define DECLARE_HANDLE(h) dns_handle_t h
#define INIT_HANDLE(h) ((h = dns_open(NULL)) != NULL)
#define SEARCH(h, n, c, t, a, l) dns_search(h, n, c, t, a, l, NULL, NULL)
diff --git a/src/lib/krb5/os/dnsglue.h b/src/lib/krb5/os/dnsglue.h
index b87e238..e784404 100644
--- a/src/lib/krb5/os/dnsglue.h
+++ b/src/lib/krb5/os/dnsglue.h
@@ -33,9 +33,9 @@
* BIND 4 doesn't have the ns_initparse() API, so we need to do some
* manual parsing via the HEADER struct. BIND 8 does have
* ns_initparse(), but has enums for the various protocol constants
- * rather than the BIND 4 macros. BIND 9 (at least on Mac OS X
- * Panther) appears to disable res_nsearch() if BIND_8_COMPAT is
- * defined (which is necessary to obtain the HEADER struct).
+ * rather than the BIND 4 macros. BIND 9 (at least on macOS 10.3)
+ * appears to disable res_nsearch() if BIND_8_COMPAT is defined
+ * (which is necessary to obtain the HEADER struct).
*
* We use ns_initparse() if available at all, and never define
* BIND_8_COMPAT. If there is no ns_initparse(), we do manual parsing
diff --git a/src/lib/krb5/os/sendto_kdc.c b/src/lib/krb5/os/sendto_kdc.c
index fffe026..8b46148 100644
--- a/src/lib/krb5/os/sendto_kdc.c
+++ b/src/lib/krb5/os/sendto_kdc.c
@@ -253,7 +253,7 @@ cm_get_ssflags(struct select_state *selstate, int fd)
struct pollfd *pfd = find_pollfd(selstate, fd);
/*
- * OS X sets POLLHUP without POLLOUT on connection error. Catch this as
+ * macOS sets POLLHUP without POLLOUT on connection error. Catch this as
* well as other error events such as POLLNVAL, but only if POLLIN and
* POLLOUT aren't set, as we can get POLLHUP along with POLLIN with TCP
* data still to be read.
diff --git a/src/man/krb5.conf.man b/src/man/krb5.conf.man
index e035072..35a4de5 100644
--- a/src/man/krb5.conf.man
+++ b/src/man/krb5.conf.man
@@ -346,7 +346,7 @@ For security reasons, .k5login files must be owned by
the local user or by root.
.TP
.B \fBkcm_mach_service\fP
-On OS X only, determines the name of the bootstrap service used to
+On macOS only, determines the name of the bootstrap service used to
contact the KCM daemon for the KCM credential cache type. If the
value is \fB\-\fP, Mach RPC will not be used to contact the KCM
daemon. The default value is \fBorg.h5l.kcm\fP\&.
diff --git a/src/util/depfix.pl b/src/util/depfix.pl
index c8df54c..9982fa0 100644
--- a/src/util/depfix.pl
+++ b/src/util/depfix.pl
@@ -147,7 +147,7 @@ sub do_subs_2 {
s;com_err.h ;\$(COM_ERR_DEPS) ;g;
}
if ($thisdir eq "lib/krb5/ccache") {
- # These files are only used (and kcmrpc.h only generated) on OS X.
+ # These files are only used (and kcmrpc.h only generated) on macOS.
# There are conditional dependencies in Makefile.in.
s;kcmrpc.h ;;g;
s;kcmrpc_types.h ;;g;
diff --git a/src/util/support/cache-addrinfo.h b/src/util/support/cache-addrinfo.h
index a1b7fb2..40752ab 100644
--- a/src/util/support/cache-addrinfo.h
+++ b/src/util/support/cache-addrinfo.h
@@ -52,12 +52,12 @@
* the data structures and flag values locally.
*
*
- * On Mac OS X, getaddrinfo results aren't cached (though
- * gethostbyname results are), so we need to build a cache here. Now
- * things are getting really messy. Because the cache is in use, we
- * use getservbyname, and throw away thread safety. (Not that the
- * cache is thread safe, but when we get locking support, that'll be
- * dealt with.) This code needs tearing down and rebuilding, soon.
+ * On macOS, getaddrinfo results aren't cached (though gethostbyname
+ * results are), so we need to build a cache here. Now things are
+ * getting really messy. Because the cache is in use, we use
+ * getservbyname, and throw away thread safety. (Not that the cache
+ * is thread safe, but when we get locking support, that'll be dealt
+ * with.) This code needs tearing down and rebuilding, soon.
*
*
* Note that recent Windows developers' code has an interesting hack:
diff --git a/src/util/support/fake-addrinfo.c b/src/util/support/fake-addrinfo.c
index b71cff9..3ee162e 100644
--- a/src/util/support/fake-addrinfo.c
+++ b/src/util/support/fake-addrinfo.c
@@ -52,7 +52,7 @@
* the data structures and flag values locally.
*
*
* On Mac OS X, getaddrinfo results aren't cached (though
* gethostbyname results are), so we need to build a cache here. Now
* things are getting really messy. Because the cache is in use, we
* use getservbyname, and throw away thread safety. (Not that the
@@ -685,7 +685,7 @@ static inline int fai_add_hosts_by_name (const char *name,
sometimes associates it with the specified service,
sometimes not.
- But on Mac OS X (10.3, 10.4) they've "extended" getaddrinfo
+ But on macOS (10.3, 10.4) they've "extended" getaddrinfo
to make SRV RR queries. (Please, somebody, show me
something in the specs that actually supports this? RFC
3493 says nothing about it, but it does say getaddrinfo is
@@ -52,7 +52,7 @@
*
*
- * On Mac OS X, getaddrinfo results aren't cached (though
+ * On macOS, getaddrinfo results aren't cached (though
* gethostbyname results are), so we need to build a cache here. Now
* things are getting really messy. Because the cache is in use, we